package com.aclr.management.person;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.opencms.main.CmsLog;
import org.opencms.main.OpenCms;

public class PersonDaoImpl implements PersonDao {

	/**
	 * Constructor de la clase.
	 */
	public PersonDaoImpl() {

	}

	@Override
	public void delete(final Person person) {
		try {
			// Se obtiene el nombre de la BD
			String databaseName = Messages.get().getBundle().key(
					Messages.DATABASE_NAME);
			// Se establece la conexion con la bd
			Connection con = OpenCms.getSqlManager()
					.getConnection(databaseName);
			PreparedStatement stmt = con
					.prepareStatement("DELETE FROM PERSON WHERE PERSON_ID = ?");
			stmt.setInt(1, person.getId());
			stmt.execute();
			con.close();
		} catch (SQLException e) {
			CmsLog.INIT
					.info("Ha ocurrido un error mientras se eliminaba a la persona con id = "
							+ person.getId());
		}
	}

	@Override
	public Person find(final int id) {
		Person person = new Person();
		try {
			// Se obtiene el nombre de la BD
			String databaseName = Messages.get().getBundle().key(
					Messages.DATABASE_NAME);
			// Se establece la conexion con la bd
			Connection con = OpenCms.getSqlManager()
					.getConnection(databaseName);
			PreparedStatement stmt = con
					.prepareStatement("SELECT PERSON_ID, PERSON_NAME, PERSON_SURNAME FROM PERSON WHERE PERSON_ID = ?");
			stmt.setInt(1, id);
			ResultSet result = stmt.executeQuery();
			result.next();
			person.setId(id);
			person.setName(result.getString("PERSON_NAME"));
			person.setSurname(result.getString("PERSON_SURNAME"));
			con.close();
		} catch (SQLException e) {
			CmsLog.INIT
					.info("Ha ocurrido error mientras se obtenia a la persona con id = "
							+ id);
		}
		return person;
	}

	@Override
	public List<Person> findAll() {
		List<Person> persons = new ArrayList();
		try {
			// Se obtiene el nombre de la BD
			String databaseName = Messages.get().getBundle().key(
					Messages.DATABASE_NAME);
			// Se establece la conexion con la bd
			Connection con = OpenCms.getSqlManager()
					.getConnection(databaseName);
			PreparedStatement stmt = con
					.prepareStatement("SELECT PERSON_ID, PERSON_NAME, PERSON_SURNAME FROM PERSON");
			ResultSet result = stmt.executeQuery();
			if (result != null) {
				while (result.next()) {
					Person person = new Person();
					person.setId(result.getInt("PERSON_ID"));
					person.setName(result.getString("PERSON_NAME"));
					person.setSurname(result.getString("PERSON_SURNAME"));
					persons.add(person);
				}
			}
			con.close();
		} catch (SQLException e) {
			CmsLog.INIT
					.info("Ha ocurrido un error mientras se obtenian las personas");
		}
		return persons;
	}

	@Override
	public void save(final Person person) {
		try {
			// Se obtiene el nombre de la BD
			String databaseName = Messages.get().getBundle().key(
					Messages.DATABASE_NAME);
			// Se establece la conexion con la bd
			Connection con = OpenCms.getSqlManager()
					.getConnection(databaseName);
			PreparedStatement stmt = con
					.prepareStatement("INSERT INTO PERSON (PERSON_ID, PERSON_NAME, PERSON_SURNAME) VALUES (NULL, ?, ?)");
			stmt.setString(1, person.getName());
			stmt.setString(2, person.getSurname());
			stmt.execute();
			con.close();
		} catch (SQLException e) {
			CmsLog.INIT
					.info("Ha ocurrido error mientras se obtenia a la persona con nombre = "
							+ person.getName());
		}
	}

	@Override
	public void update(final Person person) {
		try {
			// Se obtiene el nombre de la BD
			String databaseName = Messages.get().getBundle().key(
					Messages.DATABASE_NAME);
			// Se establece la conexion con la bd
			Connection con = OpenCms.getSqlManager()
					.getConnection(databaseName);
			PreparedStatement stmt = con
					.prepareStatement("UPDATE PERSON WHERE PERSON_ID = ? SET PERSON_NAME = ?, PERSON_SURNAME = ?");
			stmt.setInt(1, person.getId());
			stmt.setString(2, person.getName());
			stmt.setString(3, person.getSurname());
			stmt.execute();
			con.close();
		} catch (SQLException e) {
			CmsLog.INIT
					.info("Ha ocurrido error mientras se obtenia a la persona con id = "
							+ person.getId());
		}
	}
}