package com.aclr.management.person;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Hashtable;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.PageContext;

import org.opencms.widgets.CmsInputWidget;
import org.opencms.workplace.CmsWidgetDialog;
import org.opencms.workplace.CmsWidgetDialogParameter;
import org.opencms.workplace.CmsWorkplaceSettings;

/**
 * Clase que representa el formulario de edición de una persona.
 */
public class PersonEdit extends CmsWidgetDialog {

	/**
	 * Atributo que representa el prefijo del formulario.
	 */
	private static final String KEY_PREFIX = "personmanagement";

	/**
	 * Atributo que representa las páginas que conformarán el formulario de alta
	 * de una persona.
	 */
	private static final String[] PAGE_ARRAY = { "person_info" };

	/**
	 * Atributo que contiene las páginas que conformarán el formulario de alta
	 * de una persona.
	 */
	private static final List PAGE_LIST = Arrays.asList(PAGE_ARRAY);

	/**
	 * Objeto de la clase Person, es necesario para mapear los valores de la
	 * persona a crear con los campos del formulario.
	 */
	private Person person;

	/**
	 * Atributo que contendrá un texto de información.
	 */
	private String infoText;

	/**
	 * Constructor de la clase.
	 */
	public PersonEdit(final PageContext context, final HttpServletRequest req,
			final HttpServletResponse res) {
		super(context, req, res);
		person = new Person();
	}

	/**
	 * Método observador del atributo infoText.
	 */
	public String getInfoText() {
		return this.infoText;
	}

	/**
	 * Método modificador del atributo infoText.
	 */
	public void setInfoText(final String infoText) {
		this.infoText = infoText;
	}

	/**
	 * Método que realiza las acciones necesarias para editar los datos de una
	 * persona.
	 */
	public void actionCommit() throws IOException, ServletException {
		List errors = new ArrayList();
		// Obtenemos la persona cambiada.
		Person changedPerson = (Person) ((Hashtable) (getSettings()
				.getDialogObject())).get(this.getClass().getName());
		PersonDao personDAO = new PersonDaoImpl();
		personDAO.update(changedPerson);
		this.person = null;
		setCommitErrors(errors);
	}

	/**
	 * Método que inicializa el workplace con los datos del formulario.
	 */
	protected void initWorkplaceRequestValues(
			final CmsWorkplaceSettings settings,
			final HttpServletRequest request) {
		setKeyPrefix(KEY_PREFIX);
		super.initWorkplaceRequestValues(settings, request);
		setDialogObject(this.person);
	}

	/**
	 * Método que define los widgets que conformarán el formulario.
	 */
	protected void defineWidgets() {
		String personId = getJsp().getRequest().getParameter("personId");
		if (personId == null) {
			this.person = new Person();
		} else {
			PersonDao personDAO = new PersonDaoImpl();
			this.person = (Person) personDAO.find((new Integer(personId)).intValue());
			// Guardamos en sesión el municipio original
			this.getSession().setAttribute("oldPerson", this.person);
		}
		addWidget(new CmsWidgetDialogParameter(this.person, "name",
				PAGE_ARRAY[0], new CmsInputWidget()));
		addWidget(new CmsWidgetDialogParameter(this.person, "surname",
				PAGE_ARRAY[0], new CmsInputWidget()));
	}

	/**
	 * Método que inicializa el objeto de gestión de mensajes.
	 */
	protected void initMessages() {
		addMessages(Messages.get().getBundleName());
		super.initMessages();
	}

	/**
	 * Método observador del atributo PAGE_ARRAY.
	 */
	protected String[] getPageArray() {
		return PAGE_ARRAY;
	}
}